summaryrefslogtreecommitdiffstats
path: root/korn/dcopdrop.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korn/dcopdrop.cpp')
-rw-r--r--korn/dcopdrop.cpp42
1 files changed, 21 insertions, 21 deletions
diff --git a/korn/dcopdrop.cpp b/korn/dcopdrop.cpp
index 906f268de..407a6ff06 100644
--- a/korn/dcopdrop.cpp
+++ b/korn/dcopdrop.cpp
@@ -26,16 +26,16 @@
#include <kconfigbase.h>
#include <kdebug.h>
-#include <qdatetime.h>
-#include <qmap.h>
-#include <qstring.h>
-#include <qtimer.h>
+#include <tqdatetime.h>
+#include <tqmap.h>
+#include <tqstring.h>
+#include <tqtimer.h>
DCOPDrop::DCOPDrop()
: KMailDrop(),
_isRunning( false ),
- _msgList( new QMap< int, KornMailSubject* > ),
- _name( new QString( "" ) ),
+ _msgList( new TQMap< int, KornMailSubject* > ),
+ _name( new TQString( "" ) ),
_counter( 1 ),
_interface( 0 )
{
@@ -72,7 +72,7 @@ bool DCOPDrop::readConfigGroup( const KConfigGroup &cfg )
return KMailDrop::readConfigGroup( cfg );
}
-bool DCOPDrop::readConfigGroup( const QMap< QString, QString > &map, const Protocol * )
+bool DCOPDrop::readConfigGroup( const TQMap< TQString, TQString > &map, const Protocol * )
{
if( !map.contains( "dcopname" ) )
//The mapping MUST contain dcopname.
@@ -93,12 +93,12 @@ bool DCOPDrop::writeConfigGroup( KConfigBase& cfg ) const
return true;
}
-QString DCOPDrop::type() const
+TQString DCOPDrop::type() const
{
- return QString( "dcop" );
+ return TQString( "dcop" );
}
-QValueVector< KornMailSubject >* DCOPDrop::doReadSubjects( bool * )
+TQValueVector< KornMailSubject >* DCOPDrop::doReadSubjects( bool * )
{
emit readSubjectsTotalSteps( 1 );
@@ -106,19 +106,19 @@ QValueVector< KornMailSubject >* DCOPDrop::doReadSubjects( bool * )
* This way, the function is really asynchrone.
* So, the return value arraves before any data arrives.
*/
- QTimer::singleShot( 1, this, SLOT( doReadSubjectsASync( void ) ) );
+ TQTimer::singleShot( 1, this, TQT_SLOT( doReadSubjectsASync( void ) ) );
/*
* A empty QValueVector is made here.
* After that, the size is expanded to the expected number of subjects.
* This way, reallocation of memmory is minimized, and thus more efficient.
*/
- QValueVector<KornMailSubject> *vector = new QValueVector<KornMailSubject>( );
+ TQValueVector<KornMailSubject> *vector = new TQValueVector<KornMailSubject>( );
vector->reserve( _msgList->count() );
return vector;
}
-bool DCOPDrop::deleteMails( QPtrList<const KornMailId> * ids, bool * )
+bool DCOPDrop::deleteMails( TQPtrList<const KornMailId> * ids, bool * )
{
emit deleteMailsTotalSteps( 1 );
@@ -137,7 +137,7 @@ bool DCOPDrop::deleteMails( QPtrList<const KornMailId> * ids, bool * )
void DCOPDrop::eraseList( void )
{
- QMap<int, KornMailSubject* >::iterator it;
+ TQMap<int, KornMailSubject* >::iterator it;
for( it = _msgList->begin(); it != _msgList->end(); ++it )
delete it.data();
_msgList->clear();
@@ -145,24 +145,24 @@ void DCOPDrop::eraseList( void )
void DCOPDrop::doReadSubjectsASync( void )
{
- QMap<int, KornMailSubject* >::iterator it;
+ TQMap<int, KornMailSubject* >::iterator it;
for( it = _msgList->begin(); it != _msgList->end(); ++it )
emit readSubject( new KornMailSubject( *it.data() ) );
emit readSubjectsProgress( 1 );
emit readSubjectsReady( true );
}
-int DCOPDrop::addMessage( const QString& subject, const QString& message )
+int DCOPDrop::addMessage( const TQString& subject, const TQString& message )
{
KornIntId *id = new KornIntId( _counter );
KornMailSubject *mailsubject = new KornMailSubject( id, this );
++_counter;
mailsubject->setSubject( subject );
- mailsubject->setSender( QString( "DCOP: %1" ).arg( *_name ) );
+ mailsubject->setSender( TQString( "DCOP: %1" ).arg( *_name ) );
mailsubject->setHeader( message, true );
mailsubject->setSize( message.length() );
- mailsubject->setDate( QDateTime::currentDateTime().toTime_t() );
+ mailsubject->setDate( TQDateTime::currentDateTime().toTime_t() );
_msgList->insert( id->getId(), mailsubject );
@@ -184,12 +184,12 @@ bool DCOPDrop::removeMessage( int id )
return true;
}
-QString DCOPDrop::DCOPName() const
+TQString DCOPDrop::DCOPName() const
{
return *_name;
}
-void DCOPDrop::setDCOPName( const QString& name)
+void DCOPDrop::setDCOPName( const TQString& name)
{
*_name = name;
if( _interface )
@@ -106,19 +106,19 @@ QValueVector< KornMailSubject >* DCOPDrop::doReadSubjects( bool * )
/*
- * A empty QValueVector is made here.
+ * A empty TQValueVector is made here.
* After that, the size is expanded to the expected number of subjects.
* This way, reallocation of memmory is minimized, and thus more efficient.